==> razorqt_0.4.1.orig.tar.xz: razorqt-0.4.1/razorqt-panel/plugin-mount/translations/mount_sk_SK.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0">
<context>
    <name>MenuDiskItem</name>
    <message>
        <source>Click to access this device from other applications.</source>
        <translation>Kliknutím môžete pristupovať na toto zariadenie z iných aplikácií.</translation>
    </message>
    <message>
        <source>Click to eject this disc.</source>
        <translation>Kliknutím vysuniete tento disk.</translation>
    </message>
</context>
<context>
    <name>MountButton</name>
    <message>
        <source>Removable media/devices manager</source>
        <translation>Správca prenosných médií a zariadení</translation>
    </message>
    <message>
        <source>The device &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; is connected.</source>
        <translation>Zariadenie &lt;b&gt;&lt;nobr&gt;„%1“&lt;/nobr&gt;&lt;/b&gt; je zapojené.</translation>
    </message>
    <message>
        <source>The device &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; is removed.</source>
        <translation>Zariadenie &lt;b&gt;&lt;nobr&gt;„%1“&lt;/nobr&gt;&lt;/b&gt; je odstránené.</translation>
    </message>
    <message>
        <source>The device &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; is mounted to %2</source>
        <translation>Zariadenie &lt;b&gt;&lt;nobr&gt;„%1“&lt;/nobr&gt;&lt;/b&gt; je pripojené do %2</translation>
    </message>
    <message>
        <source>The device &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; is unmounted&lt;br&gt;
Now you can eject USB Flash or CD/DVD Disk.</source>
        <translation>Zariadenie &lt;b&gt;&lt;nobr&gt;„%1“&lt;/nobr&gt;&lt;/b&gt; je odpojené&lt;br&gt;
Teraz môžete vybrať USB disk alebo vysunúť CD/DVD.</translation>
    </message>
    <message>
        <source>Can&apos;t mount device: %1&lt;br&gt;
%2</source>
        <translation>Nemožno pripojiť zariadenie %1&lt;br&gt; %2</translation>
    </message>
    <message>
        <source>Device &apos;%1&apos; is mounted to %2</source>
        <translation>Zariadenie „%1“ je pripojené do %2</translation>
    </message>
    <message>
        <source>Can&apos;t unmount device: %1&lt;br&gt;
%2</source>
        <translation>Nemožno odpojiť zariadenie %1&lt;br&gt; %2</translation>
    </message>
    <message>
        <source>Device &apos;%1&apos; is unmounted</source>
        <translation>Zariadenie „%1“ je odpojené</translation>
    </message>
    <message>
        <source>No devices Available.</source>
        <translation>Žiadne zariadenia nie sú dostupné.</translation>
    </message>
</context>
<context>
    <name>RazorMountConfiguration</name>
    <message>
        <source>Razor Removable media manager settings</source>
        <translation>Nastavenia správcu prenosných médií prostredia Razor</translation>
    </message>
    <message>
        <source>Behaviour</source>
        <translation>Správanie</translation>
    </message>
    <message>
        <source>When a device is connected </source>
        <translation>Pri pripojení zariadenia </translation>
    </message>
    <message>
        <source>Popup menu</source>
        <translation>Zobraziť menu</translation>
    </message>
    <message>
        <source>Show info</source>
        <translation>Zobraziť informácie</translation>
    </message>
    <message>
        <source>Do nothing</source>
        <translation>Nerobiť nič</translation>
    </message>
</context>
</TS>

==> razorqt_0.5.2.orig.tar.xz: razorqt-0.5.2/razorqt-panel/plugin-mount/translations/mount_sk_SK.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="sk_SK" version="2.0">
<context>
    <name>MenuDiskItem</name>
    <message>
        <source>Click to access this device from other applications.</source>
        <translation>Kliknutím môžete pristupovať na toto zariadenie z iných aplikácií.</translation>
    </message>
    <message>
        <source>Click to eject this disc.</source>
        <translation>Kliknutím vysuniete tento disk.</translation>
    </message>
</context>
<context>
    <name>MountButton</name>
    <message>
        <source>Removable media/devices manager</source>
        <translation>Správca prenosných médií a zariadení</translation>
    </message>
    <message>
        <source>The device &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; is connected.</source>
        <translation>Zariadenie &lt;b&gt;&lt;nobr&gt;„%1“&lt;/nobr&gt;&lt;/b&gt; je zapojené.</translation>
    </message>
    <message>
        <source>The device &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; is removed.</source>
        <translation>Zariadenie &lt;b&gt;&lt;nobr&gt;„%1“&lt;/nobr&gt;&lt;/b&gt; je odstránené.</translation>
    </message>
</context>
<context>
    <name>Popup</name>
    <message>
        <source>No devices are available</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>RazorMountConfiguration</name>
    <message>
        <source>Razor Removable media manager settings</source>
        <translation>Nastavenia správcu prenosných médií prostredia Razor</translation>
    </message>
    <message>
        <source>Behaviour</source>
        <translation>Správanie</translation>
    </message>
    <message>
        <source>When a device is connected </source>
        <translation>Pri pripojení zariadenia </translation>
    </message>
    <message>
        <source>Popup menu</source>
        <translation>Zobraziť menu</translation>
    </message>
    <message>
        <source>Show info</source>
        <translation>Zobraziť informácie</translation>
    </message>
    <message>
        <source>Do nothing</source>
        <translation>Nerobiť nič</translation>
    </message>
</context>
</TS>
